@@ -21,15 +21,21 @@ from redshift_client.schema.core import (
     Quota,
     SchemaPolicy,
 )
-from redshift_client.sql_client.core import (
+from redshift_client.sql_client import (
+    QueryValues,
     SqlClient,
 )
+from redshift_client.sql_client.primitive import (
+    PrimitiveVal,
+)
 from redshift_client.sql_client.query import (
     dynamic_query,
     new_query,
 )
 from typing import (
+    Dict,
     FrozenSet,
+    Optional,
     TypeVar,
 )
 
@@ -68,9 +74,9 @@ class SchemaClient:
             "WHERE table_schema = %(schema_name)s",
         )
         stm = " ".join(_stm)
-
+        args: Dict[str, PrimitiveVal] = {"schema_name": schema.name}
         return self._db_client.execute(
-            new_query(stm), FrozenDict({"schema_name": schema.name})
+            new_query(stm), QueryValues(FrozenDict(args))
         ) + self._db_client.fetch_all().map(
             lambda i: frozenset(
                 TableId(schema, to_primitive(e.data[0], str).unwrap())
@@ -85,8 +91,9 @@ class SchemaClient:
             "WHERE nspname = %(schema_name)s)",
         )
         stm = " ".join(_stm)
+        args: Dict[str, PrimitiveVal] = {"schema_name": schema.name}
         return self._db_client.execute(
-            new_query(stm), FrozenDict({"schema_name": schema.name})
+            new_query(stm), QueryValues(FrozenDict(args))
         ) + self._db_client.fetch_one().map(lambda x: x.value_or(None)).map(
             lambda i: _assert_bool(i.data[0])
             if i is not None
@@ -137,19 +144,14 @@ class SchemaClient:
             ),
             None,
         )
+        id_args: Dict[str, Optional[str]] = {"schema": schema.name}
+        args: Dict[str, PrimitiveVal] = (
+            {"quota": policy.quota.value}
+            if isinstance(policy.quota, Quota)
+            else {}
+        )
         set_quota = self._db_client.execute(
-            dynamic_query(
-                stm2,
-                FrozenDict(
-                    {
-                        "schema": schema.name,
-                    }
-                ),
-            ),
-            FrozenDict(
-                {"quota": policy.quota.value}
-                if isinstance(policy.quota, Quota)
-                else {}
-            ),
+            dynamic_query(stm2, FrozenDict(id_args)),
+            QueryValues(FrozenDict(args)),
         )
         return set_owner + set_quota
