@@ -16,11 +16,14 @@ from redshift_client.data_type.core import (
 from redshift_client.id_objs import (
     TableId,
 )
-from redshift_client.sql_client.core import (
-    PrimitiveVal,
+from redshift_client.sql_client import (
+    QueryValues,
     RowData,
     SqlClient,
 )
+from redshift_client.sql_client.primitive import (
+    PrimitiveVal,
+)
 from redshift_client.sql_client.query import (
     dynamic_query,
     new_query,
@@ -67,12 +70,13 @@ class TableClient:
             UNLOAD ('SELECT * FROM {schema}.{table}')
             TO %(prefix)s iam_role %(role)s MANIFEST ESCAPE
         """
+        args: Dict[str, PrimitiveVal] = {"prefix": prefix, "role": role}
         return self._db_client.execute(
             dynamic_query(
                 stm,
                 FrozenDict({"schema": table.schema.name, "table": table.name}),
             ),
-            FrozenDict({"prefix": prefix, "role": role}),
+            QueryValues(FrozenDict(args)),
         ).map(lambda _: ManifestId(f"{prefix}manifest"))
 
     def load(
@@ -90,12 +94,16 @@ class TableClient:
             COPY {{schema}}.{{table}} FROM %(manifest_file)s
             iam_role %(role)s MANIFEST ESCAPE {nan_fix}
         """
+        args: Dict[str, PrimitiveVal] = {
+            "manifest_file": manifest.uri,
+            "role": role,
+        }
         return self._db_client.execute(
             dynamic_query(
                 stm,
                 FrozenDict({"schema": table.schema.name, "table": table.name}),
             ),
-            FrozenDict({"manifest_file": manifest.uri, "role": role}),
+            QueryValues(FrozenDict(args)),
         )
 
     def get(self, table: TableId) -> Cmd[Table]:
@@ -114,12 +122,13 @@ class TableClient:
                 AND table_schema = %(table_schema)s
             ORDER BY ordinal_position
         """
-
+        args: Dict[str, PrimitiveVal] = {
+            "table_schema": table.schema.name,
+            "table_name": table.name,
+        }
         exe = self._db_client.execute(
             new_query(stm),
-            FrozenDict(
-                {"table_schema": table.schema.name, "table_name": table.name}
-            ),
+            QueryValues(FrozenDict(args)),
         )
         results = self._db_client.fetch_all()
 
@@ -168,5 +177,5 @@ class TableClient:
             {f"default_{index}": c.default for index, (_, c) in enum_columns}
         )
         return self._db_client.execute(
-            dynamic_query(stm, FrozenDict(identifiers)), values
+            dynamic_query(stm, FrozenDict(identifiers)), QueryValues(values)
         )
